@@ -6,7 +6,7 @@ coherence <- function(x,split=c(".","!","?"),tvectors=tvectors,
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -14,7 +14,7 @@ coherence <- function(x,split=c(".","!","?"),tvectors=tvectors,
   
   if(is.matrix(tvectors)){
     
-    if(class(x) != "character"){
+    if(!inherits(x,"character")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
