@@ -6,7 +6,7 @@ conSIM <- function(x,y,z,c,tvectors=tvectors,breakdown=FALSE){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -14,22 +14,22 @@ conSIM <- function(x,y,z,c,tvectors=tvectors,breakdown=FALSE){
   
   if(is.matrix(tvectors)){
     
-    if(class(x) != "character"){
+    if(!inherits(x,"character")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
     
-    if(class(y) != "character"){
+    if(!inherits(y,"character")){
       y <- as.character(y)
       message("Note: y converted to character")
     }
     
-    if(class(z) != "character"){
+    if(!inherits(z,"character")){
       z <- as.character(z)
       message("Note: z converted to character")
     }
     
-    if(class(c) != "character"){
+    if(!inherits(c,"character")){
       c <- as.character(c)
       message("Note: c converted to character")
     }
