@@ -3,11 +3,11 @@
 #' @export
 #' @importFrom lsa cosine 
  
-costring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
+costring <- function(x,y,tvectors=tvectors,split=" ",remove.punctuation=TRUE,breakdown=FALSE){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -15,12 +15,12 @@ costring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
   
   if(is.matrix(tvectors)){
     
-    if(class(x) != "character"){
+    if(!inherits(x,"character")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
     
-    if(class(y) != "character"){
+    if(!inherits(y,"character")){
       y <- as.character(y)
       message("Note: y converted to character")
     }
@@ -39,12 +39,16 @@ costring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
       
     }
     
+    if(remove.punctuation == TRUE){
+      satz1 <- gsub(satz1,pattern="[[:punct:]]",replacement = "")
+      satz2 <- gsub(satz2,pattern="[[:punct:]]",replacement = "")
+    }
     
     if(length(satz1) == 1){
-      satz1split <- strsplit(satz1,split=" ")[[1]]
+      satz1split <- strsplit(satz1,split=split)[[1]]
     }
     if(length(satz2) == 1){
-      satz2split <- strsplit(satz2,split=" ")[[1]]
+      satz2split <- strsplit(satz2,split=split)[[1]]
     }
     
     if(length(satz1)  > 1){satz1split <- satz1}
@@ -53,11 +57,15 @@ costring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
     
     used1     <- satz1split[satz1split %in% rownames(tvectors)]
     if(length(used1)==0){(warning("no element of x found in rownames(tvectors)"))
-                         return(NA)}
+                         return(NA)}else if(length(used1) < length(satz1split)){
+                           (cat("Note: not all elements in x were found in rownames(tvectors)\n\n")) 
+                         }
     
     used2     <- satz2split[satz2split %in% rownames(tvectors)]
     if(length(used2)==0){(warning("no element of y found in rownames(tvectors)"))
-                         return(NA)}
+                         return(NA)}else if(length(used1) < length(satz1split)){
+                           (cat("Note: not all elements in y were found in rownames(tvectors)\n\n")) 
+                         }
     
     rest1    <- satz1split[!(satz1split %in% rownames(tvectors))]
     rest2    <- satz2split[!(satz2split %in% rownames(tvectors))]
@@ -72,9 +80,9 @@ costring <- function(x,y,tvectors=tvectors,breakdown=FALSE){
     
     #   out <- list(cos=cos,used1=used1,used2=used2,rest1=rest1,rest2=rest2)
     #   print(out)
-    
+
     return(cos)
     
   }else{stop("tvectors must be a matrix!")}
   
-}
\ No newline at end of file
+}
