@@ -6,7 +6,7 @@ distance <- function(x,y,method="euclidean",tvectors=tvectors,breakdown=FALSE){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -14,12 +14,12 @@ distance <- function(x,y,method="euclidean",tvectors=tvectors,breakdown=FALSE){
   
   if(is.matrix(tvectors)){
     
-    if(class(x) != "character"){
+    if(!inherits(x,"character")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
     
-    if(class(y) != "character"){
+    if(!inherits(y,"character")){
       y <- as.character(y)
       message("Note: y converted to character")
     }
