@@ -8,7 +8,7 @@ neighbors <- function(x,n,tvectors=tvectors,breakdown=FALSE){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -16,13 +16,13 @@ neighbors <- function(x,n,tvectors=tvectors,breakdown=FALSE){
   
   if(is.matrix(tvectors)){
     
-    if(class(x) == "factor"){
+    if(inherits(x,"factor")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
     
     
-    if(class(x) == "character"){
+    if(inherits(x,"character")){
       
       if(breakdown==TRUE){satz1 <- breakdown(x)}  
       if(breakdown==FALSE){satz1 <- x} 
@@ -43,7 +43,7 @@ neighbors <- function(x,n,tvectors=tvectors,breakdown=FALSE){
       }
     }
     
-    if(class(x) == "numeric"){
+    if(inherits(x,"numeric")){
       
       satz1vec <- x
     }
