@@ -9,7 +9,7 @@ plausibility <- function(x,method,n=10,stem,tvectors=tvectors,breakdown=FALSE){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -17,13 +17,13 @@ plausibility <- function(x,method,n=10,stem,tvectors=tvectors,breakdown=FALSE){
   
   if(is.matrix(tvectors)){
     
-    if(class(x) == "factor"){
+    if(inherits(x,"factor")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
 
     
-    if(class(x) == "character"){
+    if(inherits(x,"character")){
       
       if(breakdown==TRUE){satz1 <- breakdown(x)}  
       if(breakdown==FALSE){satz1 <- x} 
@@ -46,7 +46,7 @@ plausibility <- function(x,method,n=10,stem,tvectors=tvectors,breakdown=FALSE){
     
     
     
-    if(class(x) == "numeric"){
+    if(inherits(x,"numeric")){
       
       satz1vec <- x
     }
