@@ -38,7 +38,7 @@ plot_doclist <- function(x,connect.lines="all",
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if("textmatrix" %in% class(tvectors)){
+  }else if(inherits(tvectors,"textmatrix")){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
@@ -46,13 +46,13 @@ plot_doclist <- function(x,connect.lines="all",
   
   if(is.matrix(tvectors)){
     
-    if(class(x) == "factor"){
+    if(inherits(x,"factor")){
       x <- as.character(x)
       message("Note: x converted to character")
     }
     
     
-    if(class(x) == "character"){
+    if(inherits(x,"character")){
       
       if(breakdown==TRUE){satz1 <- breakdown(x)} 
       if(breakdown==FALSE){satz1 <- x}  
@@ -73,7 +73,7 @@ plot_doclist <- function(x,connect.lines="all",
     }
     
     
-    if(class(x) != "character"){
+    if(!inherits(x,"character")){
       
       stop("x must be a character vector!")    
       
@@ -227,7 +227,7 @@ plot_doclist <- function(x,connect.lines="all",
       
       
       
-      if(class(connect.lines) == "numeric" && connect.lines > 0){
+      if(inherits(connect.lines,"numeric") && connect.lines > 0){
         
         ### Find nearest to each word
         
